# -*- coding: utf-8 -*-
# @Time    : 2020/12/19 4:14 下午
# @Author  : haohao
# @FileName: test_case1.py

# content of test_sample.py


class learnPack:
    def learnpack(self,a):
        print(a)

if __name__ == "__main__":
    # pytest.main(["-s", "test_case1.py"])
    learnPack().learnpack('type1')