# -*- coding: utf-8 -*-
# @Time    : 2021/1/13 4:42 下午
# @Author  : haohao
# @FileName: setup.py
from setuptools import find_packages,setup

setup(
    name='learnpack',
    version='1.0.3',
    author='haohao',
    packages = find_packages(),
)